@@ -368,10 +368,18 @@ if (FALSE)
     }
 }    
     
+    ## Defining the inverse function
+    invfct <- function(y, parm) 
+    {
+        parmVec[notFixed] <- parm
+        
+        exp(log(((parmVec[3] - parmVec[2])/(y - parmVec[2]))^(1/parmVec[5]) - 1)/parmVec[1] + log(parmVec[4]))
+    }    
+    
     ## Returning the function with self starter and names
     returnList <- 
     list(fct = fct, ssfct = ssfct, names = names, deriv1 = deriv1, deriv2 = deriv2, derivx = derivx,
-    edfct = edfct, bfct = bfct,
+    edfct = edfct, bfct = bfct, inversion = invfct,
     scaleInd = scaleInd, confct=confct, anovaYes=anovaYes, lowerc=lowerLimits, upperc=upperLimits)
     # the last line is not needed in the future ('drm')
     #     , sxInd = sxInd, syInd = syInd,
